@@ -5,6 +5,7 @@ import openbabel as ob
 import pybel
 from tempfile import mkdtemp
 from os import removedirs, unlink, system, environ, path, getcwd, chdir, system
+from shutil import rmtree
 import re
 import string
 from random import choice
@@ -129,16 +130,17 @@ class Gamess(object):
         section += " $end\n"
         return section
 
-    def gamess_input(self, mol):
+    def input(self, mol):
         if isinstance(mol,pybel.Molecule):
             mol = mol.OBMol
         self.contrl['mult'] = mol.GetTotalSpinMultiplicity()
+        self.contrl['icharg'] = mol.GetTotalCharge()
         gamin_tmp = self.obc.WriteString(mol)
         h = self.print_header()
         return gamin_tmp.replace(" $CONTRL COORD=CART UNITS=ANGS $END\n", h[:-1])
 
     def write_file(self, mol):
-        gamess_input_str = self.gamess_input(mol)
+        gamess_input_str = self.input(mol)
         gamess_input_file = self.tempdir + "/" + self.jobname + ".inp"
         with open(gamess_input_file, "w") as f:
             f.write(gamess_input_str)
@@ -146,7 +148,7 @@ class Gamess(object):
 
     def __del__(self):
         if not self.debug:
-            removedirs(self.tempdir)
+            rmtree(self.tempdir)
 
     def basis_type(self, basis_type):
         if basis_type in ["sto3g", "STO-3G"]:
@@ -184,7 +186,7 @@ if __name__ == '__main__':
 
     mol = ob.OBMol()
     next = obc.ReadFile(mol, "examples/CID_674.sdf")
-    print g.gamess_input(mol)
+    print g.input(mol)
     try:
         newmol = g.run(mol)
     except GamessError, gerr:
